# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference import SiteReference  # noqa: F401,E501

class VolumeGroupSyncContext(ExternalizableAbstractModel):

    """Specification corresponding to the volume group synced state. The primary site reference corresponds to the cluster reference information along with the related AZ information where the entity resides. The secondary site reference corresponds to the cluster site reference information along with the related AZ information where the volume group is synced to.

    :param primary_site: (:attr:`primary_site`) 
    :type primary_site: 
    
    
    :param secondary_site: (:attr:`secondary_site`) 
    :type secondary_site: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'primary_site': 'dataprotection.v4.config.SiteReference',
        'secondary_site': 'dataprotection.v4.config.SiteReference',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'primary_site': 'primarySite',
        'secondary_site': 'secondarySite',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, primary_site=None, secondary_site=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__primary_site = None
        self.__secondary_site = None
        self.discriminator = None
        if primary_site is not None:
            self.__primary_site = primary_site
        if secondary_site is not None:
            self.__secondary_site = secondary_site

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VolumeGroupSyncContext'

    def _initialize_object_version(self):
        return 'v4.r1'


    @property
    def primary_site(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference`
        """  # noqa: E501
        return self.__primary_site

    @primary_site.setter
    def primary_site(self, primary_site):

        self.__primary_site = primary_site

    @property
    def secondary_site(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference`
        """  # noqa: E501
        return self.__secondary_site

    @secondary_site.setter
    def secondary_site(self, secondary_site):

        self.__secondary_site = secondary_site

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VolumeGroupSyncContext, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeGroupSyncContext):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_dataprotection_py_client.models
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VmRecoveryPointapplication_consistent_properties import VmRecoveryPointapplication_consistent_properties  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseVmRecoveryPoint import BaseVmRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType import HypervisorType  # noqa: F401,E501

class VmRecoveryPoint(BaseVmRecoveryPoint):

    """A model that represents VM recovery point properties.

    :param hypervisor_type: (:attr:`hypervisor_type`) 
    :type hypervisor_type: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'hypervisor_type': 'dataprotection.v4.config.HypervisorType',
        'consistency_group_ext_id': 'str',
        'disk_recovery_points': 'list[dataprotection.v4.common.DiskRecoveryPoint]',
        'vm_ext_id': 'str',
        'vm_categories': 'list[str]',
        'application_consistent_properties': 'OneOfdataprotection.v4.common.BaseVmRecoveryPointapplication_consistent_properties',
        'location_agnostic_id': 'str',
        'name': 'str',
        'creation_time': 'datetime',
        'expiration_time': 'datetime',
        'status': 'dataprotection.v4.common.RecoveryPointStatus',
        'recovery_point_type': 'dataprotection.v4.common.RecoveryPointType',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'hypervisor_type': 'hypervisorType',
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'disk_recovery_points': 'diskRecoveryPoints',
        'vm_ext_id': 'vmExtId',
        'vm_categories': 'vmCategories',
        'application_consistent_properties': 'applicationConsistentProperties',
        'location_agnostic_id': 'locationAgnosticId',
        'name': 'name',
        'creation_time': 'creationTime',
        'expiration_time': 'expirationTime',
        'status': 'status',
        'recovery_point_type': 'recoveryPointType',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, hypervisor_type=None, consistency_group_ext_id=None, disk_recovery_points=None, vm_ext_id=None, vm_categories=None, application_consistent_properties=None, location_agnostic_id=None, name=None, creation_time=None, expiration_time=None, status=None, recovery_point_type=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        BaseVmRecoveryPoint.__init__(self, consistency_group_ext_id, disk_recovery_points, vm_ext_id, vm_categories, application_consistent_properties, location_agnostic_id, name, creation_time, expiration_time, status, recovery_point_type, ext_id, links, tenant_id, *args, **kwargs)
        self.__hypervisor_type = None
        self.discriminator = None
        if hypervisor_type is not None:
            self.__hypervisor_type = hypervisor_type

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VmRecoveryPoint'

    def _initialize_object_version(self):
        return 'v4.r1'


    @property
    def hypervisor_type(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.HypervisorType`
        """  # noqa: E501
        return self.__hypervisor_type

    @hypervisor_type.setter
    def hypervisor_type(self, hypervisor_type):

        self.__hypervisor_type = hypervisor_type

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_dataprotection_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmRecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmRecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmDiskRecoveryPointClusterDiscoverSpec import VmDiskRecoveryPointClusterDiscoverSpec  # noqa: F401,E501

class VmRecoveryPointChangedRegionsComputeSpec(VmDiskRecoveryPointClusterDiscoverSpec):

    """Compute changed region parameters. These parameters allow you to specify a start offset, length, block size, and a reference disk recovery point. All parameters are optional. However, if you need to set a reference disk recovery point, you must specify all three parameters: recovery point ID, VM recovery point ID, and disk recovery point ID.

    :param offset: (:attr:`offset`) The start offset value to compute the changed region. If the value is not provided, then the difference is executed from the offset of 0. Note: the start offset might automatically align to a system-defined block boundary.
    :type offset: 
    
    
    :param length: (:attr:`length`) The length to compute the changed region. If the value is not provided, then the difference is performed from the start offset to the end of the disk. Note: the end offset might automatically align to a system-defined block boundary.
    :type length: 
    
    
    :param block_size_byte: (:attr:`block_size_byte`) When blockSizeByte is set, all returned ranges will start and end at blockSize addresses, and the changed blocks will match the block size. Supported values of blockSizeByte are [32768, 65536, 131072, 262144]. Example: if blockSizeByte is set to 32768 (i.e 32KB), all ranges will start at multiple of 32KB and end at multiple of 32KB value.
    :type block_size_byte: 
    
     min=32768, max=262144

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'offset': 'int',
        'length': 'int',
        'block_size_byte': 'int',
        'reference_vm_recovery_point_ext_id': 'str',
        'reference_recovery_point_ext_id': 'str',
        'reference_disk_recovery_point_ext_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'offset': 'offset',
        'length': 'length',
        'block_size_byte': 'blockSizeByte',
        'reference_vm_recovery_point_ext_id': 'referenceVmRecoveryPointExtId',
        'reference_recovery_point_ext_id': 'referenceRecoveryPointExtId',
        'reference_disk_recovery_point_ext_id': 'referenceDiskRecoveryPointExtId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, offset=None, length=None, block_size_byte=None, reference_vm_recovery_point_ext_id=None, reference_recovery_point_ext_id=None, reference_disk_recovery_point_ext_id=None, *args, **kwargs):  # noqa: E501
        VmDiskRecoveryPointClusterDiscoverSpec.__init__(self, reference_vm_recovery_point_ext_id, reference_recovery_point_ext_id, reference_disk_recovery_point_ext_id, *args, **kwargs)
        self.__offset = None
        self.__length = None
        self.__block_size_byte = None
        self.discriminator = None
        if offset is not None:
            self.__offset = offset
        if length is not None:
            self.__length = length
        if block_size_byte is not None:
            self.__block_size_byte = block_size_byte

    def _initialize_object_type(self):
        return 'dataprotection.v4.content.VmRecoveryPointChangedRegionsComputeSpec'

    def _initialize_object_version(self):
        return 'v4.r1'


    @property
    def offset(self):
        """
        The start offset value to compute the changed region. If the value is not provided, then the difference is executed from the offset of 0. Note: the start offset might automatically align to a system-defined block boundary.

        :type:
                :class:`~int`
        """  # noqa: E501
        return self.__offset

    @offset.setter
    def offset(self, offset):

        self.__offset = offset

    @property
    def length(self):
        """
        The length to compute the changed region. If the value is not provided, then the difference is performed from the start offset to the end of the disk. Note: the end offset might automatically align to a system-defined block boundary.

        :type:
                :class:`~int`
        """  # noqa: E501
        return self.__length

    @length.setter
    def length(self, length):

        self.__length = length

    @property
    def block_size_byte(self):
        """
        When blockSizeByte is set, all returned ranges will start and end at blockSize addresses, and the changed blocks will match the block size. Supported values of blockSizeByte are [32768, 65536, 131072, 262144]. Example: if blockSizeByte is set to 32768 (i.e 32KB), all ranges will start at multiple of 32KB and end at multiple of 32KB value.

        :type:
                :class:`~int`
        """  # noqa: E501
        return self.__block_size_byte

    @block_size_byte.setter
    def block_size_byte(self, block_size_byte):
        if block_size_byte is not None and block_size_byte > 262144:  # noqa: E501
            raise ValueError("Invalid value for `block_size_byte`, must be a value less than or equal to `262144`")  # noqa: E501
        if block_size_byte is not None and block_size_byte < 32768:  # noqa: E501
            raise ValueError("Invalid value for `block_size_byte`, must be a value greater than or equal to `32768`")  # noqa: E501

        self.__block_size_byte = block_size_byte

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmRecoveryPointChangedRegionsComputeSpec, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmRecoveryPointChangedRegionsComputeSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.CategoryReference import CategoryReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.OwnershipInfo import OwnershipInfo  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmConfigOverrideSpecification import VmConfigOverrideSpecification  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreNicConfigSpecification import VmRestoreNicConfigSpecification  # noqa: F401,E501

class AhvVmOverrideSpec(VmConfigOverrideSpecification):

    """Protected resource/recovery point restore that overrides the AHV VM configuration. The specified properties will be overridden for the restored VM.

    :param name: (:attr:`name`) Name of the VM to override with. If not specified, a name is chosen by the system and returned to the task entities when complete.
    :type name: 
     max=80 chars
    
    :param description: (:attr:`description`) VM description.
    :type description: 
    
    
    :param nic_spec: (:attr:`nic_spec`) 
    :type nic_spec: 
    
    
    :param categories: (:attr:`categories`) Categories to be associated with the VM on successful restore. If not specified, the VM is provisioned without any categories.
    :type categories: 
    
    
    :param ownership_info: (:attr:`ownership_info`) 
    :type ownership_info: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'nic_spec': 'vmm.v4.ahv.config.VmRestoreNicConfigSpecification',
        'categories': 'list[vmm.v4.ahv.config.CategoryReference]',
        'ownership_info': 'vmm.v4.ahv.config.OwnershipInfo',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'nic_spec': 'nicSpec',
        'categories': 'categories',
        'ownership_info': 'ownershipInfo',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, description=None, nic_spec=None, categories=None, ownership_info=None, *args, **kwargs):  # noqa: E501
        VmConfigOverrideSpecification.__init__(self, name, description, nic_spec, categories, ownership_info, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.AhvVmOverrideSpec'

    def _initialize_object_version(self):
        return 'v4.r1'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(AhvVmOverrideSpec, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AhvVmOverrideSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_dataprotection_py_client.models
from ntnx_dataprotection_py_client.models.OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_backing_info import VmRestoreNicConfigOverrideParamsnic_backing_info  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_network_info import VmRestoreNicConfigOverrideParamsnic_network_info  # noqa: F401,E501

class VmRestoreNicConfigOverrideParams(object):

    """NIC configuration parameters that can be overridden when restoring the VM.

    :param nic_ext_id: (:attr:`nic_ext_id`) External identifier of the NIC being overridden from the VM Recovery Point. This is not preserved but is only relevant for mapping the NIC being overridden.
    :type nic_ext_id: required
    
    
    :param nic_backing_info: (:attr:`nic_backing_info`) Information about how NIC is associated with a VM.
    :type nic_backing_info: 
    
    
    :param nic_network_info: (:attr:`nic_network_info`) Networking information object for a NIC.
    :type nic_network_info: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'nic_ext_id': 'str',
        'nic_backing_info': 'OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_backing_info',
        'nic_network_info': 'OneOfvmm.v4.ahv.config.VmRestoreNicConfigOverrideParamsnic_network_info',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'nic_ext_id': 'nicExtId',
        'nic_backing_info': 'nicBackingInfo',
        'nic_network_info': 'nicNetworkInfo',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, nic_ext_id=None, nic_backing_info=None, nic_network_info=None, *args, **kwargs):  # noqa: E501
        self.__nic_ext_id = None
        self.__nic_backing_info = None
        self.__nic_network_info = None
        self.discriminator = None
        self.__nic_ext_id = nic_ext_id
        if nic_backing_info is not None:
            self.__nic_backing_info = nic_backing_info
        if nic_network_info is not None:
            self.__nic_network_info = nic_network_info
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'vmm.v4.ahv.config.VmRestoreNicConfigOverrideParams'

    def _initialize_object_version(self):
        return 'v4.r1'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def nic_ext_id(self):
        """
        External identifier of the NIC being overridden from the VM Recovery Point. This is not preserved but is only relevant for mapping the NIC being overridden.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__nic_ext_id

    @nic_ext_id.setter
    def nic_ext_id(self, nic_ext_id):
        if nic_ext_id is None:
            raise ValueError("Invalid value for `nic_ext_id`, must not be `None`")  # noqa: E501
        if nic_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', nic_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `nic_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__nic_ext_id = nic_ext_id

    @property
    def nic_backing_info(self):
        """
        Information about how NIC is associated with a VM.

        :type:
                :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreVirtualEthernetNicOverrideSpec`
        """  # noqa: E501
        return self.__nic_backing_info

    @nic_backing_info.setter
    def nic_backing_info(self, nic_backing_info):

        self.__nic_backing_info = nic_backing_info

    @property
    def nic_network_info(self):
        """
        Networking information object for a NIC.

        :type:
                :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreVirtualEthernetNicNetworkInfoOverrideSpec`
        """  # noqa: E501
        return self.__nic_network_info

    @nic_network_info.setter
    def nic_network_info(self, nic_network_info):

        self.__nic_network_info = nic_network_info

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_dataprotection_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmRestoreNicConfigOverrideParams, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmRestoreNicConfigOverrideParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.CategoryReference import CategoryReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.OwnershipInfo import OwnershipInfo  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreNicConfigSpecification import VmRestoreNicConfigSpecification  # noqa: F401,E501

class VmConfigOverrideSpecification(object):

    """To override the VM configuration captured in the snapshot (VM Recovery Point). Whatever values are specified in this object, will override the corresponding VM config entry from the snapshot. For example, if a new list of NICs are specified, the existing NIC details are replaced with the provided list. If the list of NICs is set to an empty list explicitly, the VM will be created with no NICs. For the case where the NICs are not set in the override spec at all, the NICs from the captured VM config will be attempted during restore.

    :param name: (:attr:`name`) Name of the VM to override with. If not specified, a name is chosen by the system and returned to the task entities when complete.
    :type name: 
     max=80 chars
    
    :param description: (:attr:`description`) VM description.
    :type description: 
    
    
    :param nic_spec: (:attr:`nic_spec`) 
    :type nic_spec: 
    
    
    :param categories: (:attr:`categories`) Categories to be associated with the VM on successful restore. If not specified, the VM is provisioned without any categories.
    :type categories: 
    
    
    :param ownership_info: (:attr:`ownership_info`) 
    :type ownership_info: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'nic_spec': 'vmm.v4.ahv.config.VmRestoreNicConfigSpecification',
        'categories': 'list[vmm.v4.ahv.config.CategoryReference]',
        'ownership_info': 'vmm.v4.ahv.config.OwnershipInfo',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'nic_spec': 'nicSpec',
        'categories': 'categories',
        'ownership_info': 'ownershipInfo',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, description=None, nic_spec=None, categories=None, ownership_info=None, *args, **kwargs):  # noqa: E501
        self.__name = None
        self.__description = None
        self.__nic_spec = None
        self.__categories = None
        self.__ownership_info = None
        self.discriminator = None
        if name is not None:
            self.__name = name
        if description is not None:
            self.__description = description
        if nic_spec is not None:
            self.__nic_spec = nic_spec
        if categories is not None:
            self.__categories = categories
        if ownership_info is not None:
            self.__ownership_info = ownership_info
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'vmm.v4.ahv.config.VmConfigOverrideSpecification'

    def _initialize_object_version(self):
        return 'v4.r1'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def name(self):
        """
        Name of the VM to override with. If not specified, a name is chosen by the system and returned to the task entities when complete.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is not None and len(name) > 80:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `80`")  # noqa: E501

        self.__name = name

    @property
    def description(self):
        """
        VM description.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__description

    @description.setter
    def description(self, description):

        self.__description = description

    @property
    def nic_spec(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.VmRestoreNicConfigSpecification`
        """  # noqa: E501
        return self.__nic_spec

    @nic_spec.setter
    def nic_spec(self, nic_spec):

        self.__nic_spec = nic_spec

    @property
    def categories(self):
        """
        Categories to be associated with the VM on successful restore. If not specified, the VM is provisioned without any categories.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.CategoryReference` ]
        """  # noqa: E501
        return self.__categories

    @categories.setter
    def categories(self, categories):

        self.__categories = categories

    @property
    def ownership_info(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.vmm.v4.ahv.config.OwnershipInfo`
        """  # noqa: E501
        return self.__ownership_info

    @ownership_info.setter
    def ownership_info(self, ownership_info):

        self.__ownership_info = ownership_info

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VmConfigOverrideSpecification, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VmConfigOverrideSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_dataprotection_py_client.models
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRepositoryProjectionobject_storage_reference import RecoveryPointRepositoryProjectionobject_storage_reference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ObjectStorageType import ObjectStorageType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRepository import RecoveryPointRepository  # noqa: F401,E501

class RecoveryPointRepositoryProjection(RecoveryPointRepository):

    """

    :param name: (:attr:`name`) Name of the recovery point repository.
    :type name: 
     max=256 chars
    
    :param object_storage_type: (:attr:`object_storage_type`) 
    :type object_storage_type: 
    
    
    :param object_storage_reference: (:attr:`object_storage_reference`) Object storage reference details.
    :type object_storage_reference: 
    
    
    :param ext_id: (:attr:`ext_id`) A globally unique identifier of an instance that is suitable for external consumption. 
    :type ext_id: 
    
    
    :param links: (:attr:`links`) A HATEOAS style link for the response.  Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource. 
    :type links: 
    
    
    :param tenant_id: (:attr:`tenant_id`) A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this ID to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server). 
    :type tenant_id: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'object_storage_type': 'dataprotection.v4.config.ObjectStorageType',
        'object_storage_reference': 'OneOfdataprotection.v4.config.RecoveryPointRepositoryobject_storage_reference',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'object_storage_type': 'objectStorageType',
        'object_storage_reference': 'objectStorageReference',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, object_storage_type=None, object_storage_reference=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        RecoveryPointRepository.__init__(self, name, object_storage_type, object_storage_reference, ext_id, links, tenant_id, *args, **kwargs)
        self.discriminator = None

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.RecoveryPointRepositoryProjection'

    def _initialize_object_version(self):
        return 'v4.r1'


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_dataprotection_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(RecoveryPointRepositoryProjection, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecoveryPointRepositoryProjection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedEntityType import ProtectedEntityType  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteProtectionInfo import SiteProtectionInfo  # noqa: F401,E501

class ProtectedResource(ExternalizableAbstractModel):

    """Once a VM or volume group is associated with some protection policy, the schedule(s) in the protection policy kick in to achieve the specified recovery point objective. A protected resource represents the data protection view of such a VM or volume group. It contains information such as the restorable time ranges on the local Prism Central and the state of replication to the targets specified in all the applied protection policies.

    :param entity_ext_id: (:attr:`entity_ext_id`) The external identifier of the VM or the volume group associated with the protected resource.
    :type entity_ext_id: 
    
    
    :param entity_type: (:attr:`entity_type`) 
    :type entity_type: 
    
    
    :param source_site_reference: (:attr:`source_site_reference`) 
    :type source_site_reference: 
    
    
    :param site_protection_info: (:attr:`site_protection_info`) The data protection details of the protected resource that are relevant to any of the sites in the local Prism Central, like the time ranges available for recovery.
    :type site_protection_info: 
    
    
    :param replication_states: (:attr:`replication_states`) 
    :type replication_states: 
    
    
    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the protected resource is part of.
    :type consistency_group_ext_id: 
    
    
    :param category_fq_names: (:attr:`category_fq_names`) Category key-value pairs associated with the protected resource at the time of protection. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.
    :type category_fq_names: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'entity_ext_id': 'str',
        'entity_type': 'dataprotection.v4.config.ProtectedEntityType',
        'source_site_reference': 'dataprotection.v4.config.DataProtectionSiteReference',
        'site_protection_info': 'list[dataprotection.v4.config.SiteProtectionInfo]',
        'replication_states': 'list[dataprotection.v4.config.ReplicationState]',
        'consistency_group_ext_id': 'str',
        'category_fq_names': 'list[str]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'entity_ext_id': 'entityExtId',
        'entity_type': 'entityType',
        'source_site_reference': 'sourceSiteReference',
        'site_protection_info': 'siteProtectionInfo',
        'replication_states': 'replicationStates',
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'category_fq_names': 'categoryFqNames',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, entity_ext_id=None, entity_type=None, source_site_reference=None, site_protection_info=None, replication_states=None, consistency_group_ext_id=None, category_fq_names=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__entity_ext_id = None
        self.__entity_type = None
        self.__source_site_reference = None
        self.__site_protection_info = None
        self.__replication_states = None
        self.__consistency_group_ext_id = None
        self.__category_fq_names = None
        self.discriminator = None
        if entity_ext_id is not None:
            self.__entity_ext_id = entity_ext_id
        if entity_type is not None:
            self.__entity_type = entity_type
        if source_site_reference is not None:
            self.__source_site_reference = source_site_reference
        if site_protection_info is not None:
            self.__site_protection_info = site_protection_info
        if replication_states is not None:
            self.__replication_states = replication_states
        if consistency_group_ext_id is not None:
            self.__consistency_group_ext_id = consistency_group_ext_id
        if category_fq_names is not None:
            self.__category_fq_names = category_fq_names

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ProtectedResource'

    def _initialize_object_version(self):
        return 'v4.r1'


    @property
    def entity_ext_id(self):
        """
        The external identifier of the VM or the volume group associated with the protected resource.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__entity_ext_id

    @entity_ext_id.setter
    def entity_ext_id(self, entity_ext_id):
        if entity_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', entity_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `entity_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__entity_ext_id = entity_ext_id

    @property
    def entity_type(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedEntityType`
        """  # noqa: E501
        return self.__entity_type

    @entity_type.setter
    def entity_type(self, entity_type):

        self.__entity_type = entity_type

    @property
    def source_site_reference(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference`
        """  # noqa: E501
        return self.__source_site_reference

    @source_site_reference.setter
    def source_site_reference(self, source_site_reference):

        self.__source_site_reference = source_site_reference

    @property
    def site_protection_info(self):
        """
        The data protection details of the protected resource that are relevant to any of the sites in the local Prism Central, like the time ranges available for recovery.

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteProtectionInfo` ]
        """  # noqa: E501
        return self.__site_protection_info

    @site_protection_info.setter
    def site_protection_info(self, site_protection_info):

        self.__site_protection_info = site_protection_info

    @property
    def replication_states(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState` ]
        """  # noqa: E501
        return self.__replication_states

    @replication_states.setter
    def replication_states(self, replication_states):

        self.__replication_states = replication_states

    @property
    def consistency_group_ext_id(self):
        """
        External identifier of the Consistency group which the protected resource is part of.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__consistency_group_ext_id

    @consistency_group_ext_id.setter
    def consistency_group_ext_id(self, consistency_group_ext_id):
        if consistency_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', consistency_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `consistency_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__consistency_group_ext_id = consistency_group_ext_id

    @property
    def category_fq_names(self):
        """
        Category key-value pairs associated with the protected resource at the time of protection. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__category_fq_names

    @category_fq_names.setter
    def category_fq_names(self, category_fq_names):

        self.__category_fq_names = category_fq_names

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ProtectedResource, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtectedResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ntnx_dataprotection_py_client.api_client import ApiClient


class ProtectedResourcesApi(object):
    """IGNORE:
    NOTE: A placeholder for class level description
    IGNORE
    """  # noqa: E501

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()

        self.api_client = api_client
        self.__headers_to_skip = { 'authorization', 'cookie', 'host', 'user-agent' }

    def get_protected_resource_by_id(self, extId, **kwargs):  # noqa: E501
        """Get a protected resource

        >>> response = api.get_protected_resource_by_id(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_protected_resource_by_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier of a protected VM or volume group used to retrieve the protected resource.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetProtectedResourceApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_protected_resource_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetProtectedResourceApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetProtectedResourceApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def promote_protected_resource(self, extId, **kwargs):  # noqa: E501
        """Promote protected resource

        >>> response = api.promote_protected_resource(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.promote_protected_resource(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier of a protected VM or volume group used to retrieve the protected resource.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourcePromoteApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `promote_protected_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}/$actions/promote', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ProtectedResourcePromoteApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}/$actions/promote', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ProtectedResourcePromoteApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def restore_protected_resource(self, extId, body, **kwargs):  # noqa: E501
        """Restore protected resource

        >>> response = api.restore_protected_resource(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.restore_protected_resource(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier of a protected VM or volume group used to retrieve the protected resource.
        :type extId:
            :class:`str`, required
        :param body: Restore action specifications for a minutely scheduled protected resource.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `restore_protected_resource`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `restore_protected_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}/$actions/restore', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ProtectedResourceRestoreApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.1/config/protected-resources/{extId}/$actions/restore', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ProtectedResourceRestoreApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass
